@@ -8,6 +8,7 @@ from uuid import uuid4
 import requests
 
 import jsonutils.config as config
+from jsonutils.cache import memoized_method
 from jsonutils.encoders import JSONObjectEncoder
 from jsonutils.exceptions import (
     JSONDecodeException,
@@ -173,6 +174,7 @@ class JSONNode:
     """
 
     __odir__ = object.__dir__  # rename old __dir__ method to __odir__
+    __osetattr__ = object.__setattr__
 
     def __init__(self, *args, **kwargs):
 
@@ -247,7 +249,9 @@ class JSONNode:
                     if key in obj:
                         output_dict[key] = obj[key]._data
                         break
-                if search_upwards:
+                if (
+                    search_upwards
+                ):  # TODO search_upwards can be a number (number of recursive upwards lookings)
                     obj = obj.parent
                     if obj is None:
                         break
@@ -368,6 +372,16 @@ class JSONNode:
 
         return _notpath(self, other)
 
+    def startswith_action(self, other):
+        from jsonutils.functions.actions import _startswith
+
+        return _startswith(self, other)
+
+    def endswith_action(self, other):
+        from jsonutils.functions.actions import _endswith
+
+        return _endswith(self, other)
+
 
 class JSONCompose(JSONNode):
     """
@@ -394,17 +408,11 @@ class JSONCompose(JSONNode):
         """Any JSON object can be a child for a given compose object"""
         if isinstance(self, JSONDict):
             for key, value in self.items():
-                child = JSONObject(value)
-                child._key = key
-                child.parent = self
-                self.__setitem__(key, child)
+                self.__setitem__(key, value)
 
         elif isinstance(self, JSONList):
             for index, item in enumerate(self):
-                child = JSONObject(item)
-                child._index = index
-                child.parent = self
-                self.__setitem__(index, child)
+                self.__setitem__(index, item)
 
     def query(
         self,
