@@ -277,6 +277,20 @@ class QuerySet(list):
     def count(self):
         return self.__len__()
 
+    def delete(self):
+        if self._list_of_root_nodes:
+            return
+        deleted_objects = 0
+        for item in self:
+            path = item.parent.jsonpath.relative_to(self._root)
+            try:
+                exec(f"self._root{path}.pop(item._key)")
+            except Exception:
+                continue
+            else:
+                deleted_objects += 1
+        return deleted_objects
+
     def update(self, new_obj):
         """
         Update elements of queryset (inplace) within JSONObject from which they are derived (self._root)
@@ -361,6 +375,28 @@ class QuerySet(list):
                     output.append(item)
             return output
 
+    def filter_key(self, pattern, **q):
+        # TODO add test
+
+        cls = self.__class__
+
+        output = cls()
+        output._root = self._root
+        output._native_types = self._native_types
+
+        if (
+            self._list_of_root_nodes
+        ):  # If we are dealing with a list of root nodes, we must call the query function of each of them
+            for item in self:
+                if item.query_key(pattern, **q).exists():
+                    output.append(item)
+            return output
+        else:
+            for item in self:
+                if item.parent.query_key(pattern, **q).exists():
+                    output.append(item)
+            return output
+
     def values(self, *keys, search_upwards=True, **kwargs):
         """
         This method changes the values returned by the queryset.
@@ -525,6 +561,10 @@ class ExtractYear:
         else:
             return False
 
+class Length:
+    def __init__(self, data):
+        self.data = data
+
 
 class I:
     """Ignore case Object wrapper, for using in query_key method instead of re.compile the pattern with re.I flag"""
